# Advanced Use Cases for the Integration API
### On this page
  * [Field and Value Processing](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#field-and-value-processing)
  * [JUEL and RegEx](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#juel-and-regex)
  * [RegEx and JUEL](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#regex-and-juel)
  * [Advanced JUEL](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#advanced-juel)
  * [JUEL Use Cases](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#juel-use-cases)
  * [Best Name for Fact Sheet](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#best-name-for-fact-sheet)
  * [Using "Integration" Object](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#using-"integration"-object)
  * [Calculating with single-select fields](https://help.sap.com/docs/leanix/ea/advanced-use-cases-for-integration-api#calculating-with-single-select-fields)


View all
Explore advanced scenarios and examples for the Integration API.
